@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.190426';
+our $VERSION = '0.220625';
 
 use Acme::CPANAuthors::Register (
     ABUI      => 'DAISUKE ABUI',
@@ -34,6 +34,7 @@ use Acme::CPANAuthors::Register (
     ANNELI    => 'Yuki Izumi',
     ANZUSAN   => 'masashi nakajima',
     AONEKO    => 'Atsushi Watanabe',
+    AOYAMA    => 'Yoichi Aoyama',
     AQL       => 'Tetsuya Toyoda',
     ARGRATH   => 'SHIRAKATA Kentaro',
     ARISAWA   => 'Kosuke Arisawa',
@@ -92,6 +93,7 @@ use Acme::CPANAuthors::Register (
     GFUJI     => 'Goro Fuji',
     GOCCY     => 'Masaaki Goshima',
     GOLOGO    => 'Yohei Yamaguchi',
+    GUCCHISK  => 'Satoshi Kobayashi',
     GUNYA     => 'GUNYARA-KUN',
     GURISUGI  => 'Takuya Sugimoto',
     HAAZIME   => 'Hajime Sueyoshi',
@@ -142,6 +144,7 @@ use Acme::CPANAuthors::Register (
     HOKKE     => 'Yoichi Hirota',
     HOLLY     => 'Akira Horimoto',
     HOMESHIMA => 'Teppei Shimada',
+    HORIMOTO  => 'Horimoto Yasuhiro',
     HORIUCHI  => 'Yasuhiro Horiuchi',
     HORIYUKI  => 'Yukio HORI',
     HOTO      => 'Yuki Ishikawa',
@@ -161,6 +164,7 @@ use Acme::CPANAuthors::Register (
     IKUTA     => 'Masahito Ikuta',
     ILLO      => 'Ichito Nagata',
     INA       => 'INABA Hitoshi',
+    INABAJUN  => 'inaba jun',
     INFINITH  => 'Hiroshi Tashiro',
     INGKTDS   => 'Inagaki Tadashi',
     ISHIGAKI  => 'Kenichi Ishigaki',
@@ -175,6 +179,7 @@ use Acme::CPANAuthors::Register (
     JIRO      => 'Jiro Nishiguchi',
     JKONDO    => 'Junya Kondo',
     JUDIOO    => 'Udo Oji',
+    JUNBEAR   => 'Junko  Okuma',
     JUNICHIRO => 'Junichiro Tobe',
     JUNNAMA   => 'Junnama Noda',
     KAKUDRUMS => 'Yoichi Watanabe',
@@ -238,6 +243,7 @@ use Acme::CPANAuthors::Register (
     KOSHITA   => 'Kaoru Oshita',
     KOYACHI   => 'Tsutomu Koyachi',
     KPEE      => 'Kiyoaki KATAKURA',
+    KSAKANE   => 'sakane kenichi',
     KSUZUKI   => 'Ken Suzuki',
     KTAIGA    => 'Koji Taiga',
     KTAKATA   => 'Ken Takata',
@@ -250,6 +256,7 @@ use Acme::CPANAuthors::Register (
     KUNIYOSHI => 'Kuniyoshi Kouji',
     KURAMAKO  => 'makoto',
     KURIHARA  => 'Yoshiki KURIHARA',
+    KURIKIN   => 'Kazuhiro Yoshida',
     KURIYAMA  => 'Jun Kuriyama',
     KUZUHA    => 'Kuzuha SHINODA',
     KWATCH    => 'Makoto Kuwata',
@@ -261,6 +268,7 @@ use Acme::CPANAuthors::Register (
     KYORO     => 'Kyosuke INOUE',
     KZFM      => 'Kazufumi Ohkawa',
     KZTOMITA  => 'Kazuyoshi Tomita',
+    KZWMSYK   => 'Masayuki Kozawa',
     KZYS      => 'Kato Kazuyoshi',
     LAPIS     => 'Junichi Iwasaki',
     LAYSAKURA => 'Sho Nakatani',
@@ -338,6 +346,7 @@ use Acme::CPANAuthors::Register (
     NAGATA    => 'Ichito Nagata',
     NAHCNUJ   => 'Junichi Hayashi',
     NAITO     => 'Naoyuki Ito',
+    NAKAMURA  => 'makoto nakamura',
     NAKASHIN  => 'Shinji Nakamura',
     NAKAYAMA  => 'Yasuhiro Nakayama',
     NANTO     => 'nanto_vi (TOYAMA Nao)',
@@ -418,6 +427,7 @@ use Acme::CPANAuthors::Register (
     RYO       => 'Ryo Utsunomiya',
     RYOCHIN   => 'Okamoto RYO',
     RYOPEKO   => 'Ryoichi SEKIGUCHI',
+    RYUNOSUKE => 'Ryunosuke Murakami',
     SADAHIRO  => 'SADAHIRO Tomoyuki',
     SAITORYC  => 'Ryoichi Saito',
     SASAKURE  => 'Kei Shimada (sasakure_kei)',
@@ -434,6 +444,7 @@ use Acme::CPANAuthors::Register (
     SEAGIRL   => 'Takuho Yoshizu',
     SEI       => 'Shinichiro Sei',
     SEKIA     => 'Koichi SATOH',
+    SEKIKN    => 'Kengo Seki',
     SEKIMURA  => 'Masayoshi Sekimura',
     SERA      => 'Kazuhiro Sera',
     SEYN      => 'Yasushi Nakajima',
@@ -497,11 +508,13 @@ use Acme::CPANAuthors::Register (
     TAILRIVER => 'Shinsuke Ogawa',
     TAIY      => 'Taisuke Yamada',
     TAIYOH    => 'Taiyoh Tanaka',
+    TAKAHITO  => 'Takahito Yamada',
     TAKANORI  => 'Takanori Uzuka',
     TAKASAGO  => 'Masaaki Takasago',
     TAKASH    => 'shuhei takahashi',
     TAKASHI   => 'Takashi Saeki',
     TAKAYUKI  => 'Takayuki Ikeda',
+    TAKEASH   => 'Takehiko Shintani',
     TAKEBAYAS => 'Shun Takebayashi',
     TAKEFUMI  => 'KIMURA, takefumi',
     TAKEO     => 'Takeo Suzuki',
@@ -537,6 +550,7 @@ use Acme::CPANAuthors::Register (
     TISHIDUKA => 'Takeshi ISHIDUKA',
     TITSUKI   => 'Itsuki Toyota',
     TKURITA   => 'Tetsuro KURITA',
+    TKZWTKS   => 'Takashi Takizawa',
     TMAESAKA  => 'Toru Maesaka',
     TMITOH    => 'Tomoaki Itoh',
     TMITZ     => 'Tomohiro Mitsumune',
@@ -552,6 +566,7 @@ use Acme::CPANAuthors::Register (
     TOMBO     => 'Tomoaki Otsuka',
     TOMCHA    => 'Tomokazu Mishima',
     TOMITA    => 'Naoki Tomita',
+    TOMOYAMA  => 'Tomohiro Yamashita',
     TOMOYUKI  => 'tomoyuki okino',
     TOMYHERO  => 'Tomohiro Teranishi',
     TONODERA  => 'Takahiro Onodera',
@@ -586,6 +601,7 @@ use Acme::CPANAuthors::Register (
     UNLEARNED => 'Takashi Uesugi',
     USUALOMA  => 'Taku Amano',
     UTAANI    => 'Takeshi Ueno',
+    UTGWKK    => 'UTAGAWA KIKI',
     VPAM      => 'singo suda',
     WADACHI   => 'Satoshi Wada',
     WAKAPON   => 'ASANO Kazunari',
@@ -617,6 +633,7 @@ use Acme::CPANAuthors::Register (
     YIBE      => 'Yuki Ibe',
     YISHINO   => 'Yukio Ishino',
     YOHEIMUTA => 'Yohei Yoshimuta',
+    YOITO     => 'Yoshiyuki Ito',
     YOKKUNS   => 'Yohei Sato',
     YONJOUHAN => 'Tetsuya Yamamoto',
     YOSHIAKI  => 'Yoshiaki Shiokawa',
@@ -626,6 +643,7 @@ use Acme::CPANAuthors::Register (
     YOSIZUKA  => 'yukio kusakabe',
     YOSTY     => 'Koji Komatsu',
     YOSUKEF   => 'Yosuke Furukawa',
+    YOUPONG   => 'Yusaku NAKAJIMA',
     YOWCOW    => 'Yoko Oyama',
     YSAS      => 'Yasuhiro Sasama',
     YSASAKI   => 'Yoshihiro Sasaki',
